# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/api_user/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/api_user/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.api_user.v1 import api_user_pb2 as meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'meshtrade/iam/api_user/v1/service.proto\x12\x19meshtrade.iam.api_user.v1\x1a\x1b\x62uf/validate/validate.proto\x1a(meshtrade/iam/api_user/v1/api_user.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"\'\n\x11GetApiUserRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"7\n\x1aGetApiUserByKeyHashRequest\x12\x19\n\x08key_hash\x18\x01 \x01(\tR\x07keyHash\"U\n\x14\x43reateApiUserRequest\x12=\n\x08\x61pi_user\x18\x01 \x01(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x07\x61piUser\"\x15\n\x13ListApiUsersRequest\"W\n\x14ListApiUsersResponse\x12?\n\tapi_users\x18\x01 \x03(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x08\x61piUsers\":\n\x15SearchApiUsersRequest\x12!\n\x0c\x64isplay_name\x18\x01 \x01(\tR\x0b\x64isplayName\"Y\n\x16SearchApiUsersResponse\x12?\n\tapi_users\x18\x01 \x03(\x0b\x32\".meshtrade.iam.api_user.v1.APIUserR\x08\x61piUsers\"\xd9\x01\n\x16\x41\x63tivateApiUserRequest\x12\xbe\x01\n\x04name\x18\x01 \x01(\tB\xa9\x01\xbaH\xa5\x01r&\x10\x01\x32\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\xba\x01z\n\rname.required\x12\x35name is required and must be in format api_users/{id}\x1a\x32this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')R\x04name\"\xdb\x01\n\x18\x44\x65\x61\x63tivateApiUserRequest\x12\xbe\x01\n\x04name\x18\x01 \x01(\tB\xa9\x01\xbaH\xa5\x01r&\x10\x01\x32\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\xba\x01z\n\rname.required\x12\x35name is required and must be in format api_users/{id}\x1a\x32this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')R\x04name2\xe8\x06\n\x0e\x41piUserService\x12l\n\nGetApiUser\x12,.meshtrade.iam.api_user.v1.GetApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12q\n\rCreateApiUser\x12/.meshtrade.iam.api_user.v1.CreateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x12}\n\x0cListApiUsers\x12..meshtrade.iam.api_user.v1.ListApiUsersRequest\x1a/.meshtrade.iam.api_user.v1.ListApiUsersResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12\x83\x01\n\x0eSearchApiUsers\x12\x30.meshtrade.iam.api_user.v1.SearchApiUsersRequest\x1a\x31.meshtrade.iam.api_user.v1.SearchApiUsersResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12u\n\x0f\x41\x63tivateApiUser\x12\x31.meshtrade.iam.api_user.v1.ActivateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x12y\n\x11\x44\x65\x61\x63tivateApiUser\x12\x33.meshtrade.iam.api_user.v1.DeactivateApiUserRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x12~\n\x13GetApiUserByKeyHash\x12\x35.meshtrade.iam.api_user.v1.GetApiUserByKeyHashRequest\x1a\".meshtrade.iam.api_user.v1.APIUser\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x42Z\n co.meshtrade.api.iam.api_user.v1Z6github.com/meshtrade/api/go/iam/api_user/v1;api_userv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.api_user.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n co.meshtrade.api.iam.api_user.v1Z6github.com/meshtrade/api/go/iam/api_user/v1;api_userv1'
  _globals['_ACTIVATEAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_ACTIVATEAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H\245\001r&\020\0012\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\272\001z\n\rname.required\0225name is required and must be in format api_users/{id}\0322this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')'
  _globals['_DEACTIVATEAPIUSERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DEACTIVATEAPIUSERREQUEST'].fields_by_name['name']._serialized_options = b'\272H\245\001r&\020\0012\"^api_users/[0-9A-HJKMNP-TV-Z]{26}$\272\001z\n\rname.required\0225name is required and must be in format api_users/{id}\0322this.matches(\'^api_users/[0-9A-HJKMNP-TV-Z]{26}$\')'
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUser']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_APIUSERSERVICE'].methods_by_name['CreateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['CreateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_APIUSERSERVICE'].methods_by_name['ListApiUsers']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['ListApiUsers']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_APIUSERSERVICE'].methods_by_name['SearchApiUsers']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['SearchApiUsers']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_APIUSERSERVICE'].methods_by_name['ActivateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['ActivateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_APIUSERSERVICE'].methods_by_name['DeactivateApiUser']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['DeactivateApiUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUserByKeyHash']._loaded_options = None
  _globals['_APIUSERSERVICE'].methods_by_name['GetApiUserByKeyHash']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_GETAPIUSERREQUEST']._serialized_start=214
  _globals['_GETAPIUSERREQUEST']._serialized_end=253
  _globals['_GETAPIUSERBYKEYHASHREQUEST']._serialized_start=255
  _globals['_GETAPIUSERBYKEYHASHREQUEST']._serialized_end=310
  _globals['_CREATEAPIUSERREQUEST']._serialized_start=312
  _globals['_CREATEAPIUSERREQUEST']._serialized_end=397
  _globals['_LISTAPIUSERSREQUEST']._serialized_start=399
  _globals['_LISTAPIUSERSREQUEST']._serialized_end=420
  _globals['_LISTAPIUSERSRESPONSE']._serialized_start=422
  _globals['_LISTAPIUSERSRESPONSE']._serialized_end=509
  _globals['_SEARCHAPIUSERSREQUEST']._serialized_start=511
  _globals['_SEARCHAPIUSERSREQUEST']._serialized_end=569
  _globals['_SEARCHAPIUSERSRESPONSE']._serialized_start=571
  _globals['_SEARCHAPIUSERSRESPONSE']._serialized_end=660
  _globals['_ACTIVATEAPIUSERREQUEST']._serialized_start=663
  _globals['_ACTIVATEAPIUSERREQUEST']._serialized_end=880
  _globals['_DEACTIVATEAPIUSERREQUEST']._serialized_start=883
  _globals['_DEACTIVATEAPIUSERREQUEST']._serialized_end=1102
  _globals['_APIUSERSERVICE']._serialized_start=1105
  _globals['_APIUSERSERVICE']._serialized_end=1977
# @@protoc_insertion_point(module_scope)



"""Role helper functions for IAM role management."""

from .role_pb2 import Role


def full_resource_name_from_group_name(role: Role, group_name: str) -> str:
    """
    Create a full resource name for a role within a specific group.

    This function provides the Python equivalent of Go's Role.FullResourceNameFromGroupName() method.

    Args:
        role: The Role enum value (e.g., Role.ROLE_IAM_ADMIN)
        group_name: The group name (e.g., "groups/01DD32GZ7R0000000000000001")

    Returns:
        The full resource name string (e.g., "groups/01DD32GZ7R0000000000000001/5")

    Example:
        >>> full_resource_name_from_group_name(Role.ROLE_IAM_ADMIN, "groups/01DD32GZ7R0000000000000001")
        "groups/01DD32GZ7R0000000000000001/5"
    """
    return f"{group_name}/{role}"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/tax_residency.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/tax_residency.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/compliance/client/v1/tax_residency.proto\x12\x1emeshtrade.compliance.client.v1\"C\n\x0cTaxResidency\x12!\n\x0c\x63ountry_code\x18\x01 \x01(\tR\x0b\x63ountryCode\x12\x10\n\x03tin\x18\x02 \x01(\tR\x03tinBb\n%co.meshtrade.api.compliance.client.v1Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.tax_residency_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z9github.com/meshtrade/api/go/compliance/client/v1;clientv1'
  _globals['_TAXRESIDENCY']._serialized_start=86
  _globals['_TAXRESIDENCY']._serialized_end=153
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.iam.api_user.v1 import api_user_pb2 as meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2
from meshtrade.iam.api_user.v1 import service_pb2 as meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2


class ApiUserServiceStub(object):
    """
    ApiUserService manages API user lifecycle and authentication credentials.

    API users represent automated clients that can authenticate with API keys
    and perform operations within a specific group context. Each API user has:
    - A unique identifier and display name
    - Group ownership for resource isolation
    - Role-based permissions for authorization
    - Active/inactive state for access control

    All operations require IAM domain permissions and operate within
    the authenticated group context.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetApiUser = channel.unary_unary(
                '/meshtrade.iam.api_user.v1.ApiUserService/GetApiUser',
                request_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.GetApiUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
                _registered_method=True)
        self.CreateApiUser = channel.unary_unary(
                '/meshtrade.iam.api_user.v1.ApiUserService/CreateApiUser',
                request_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.CreateApiUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
                _registered_method=True)
        self.ListApiUsers = channel.unary_unary(
                '/meshtrade.iam.api_user.v1.ApiUserService/ListApiUsers',
                request_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ListApiUsersRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ListApiUsersResponse.FromString,
                _registered_method=True)
        self.SearchApiUsers = channel.unary_unary(
                '/meshtrade.iam.api_user.v1.ApiUserService/SearchApiUsers',
                request_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.SearchApiUsersRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.SearchApiUsersResponse.FromString,
                _registered_method=True)
        self.ActivateApiUser = channel.unary_unary(
                '/meshtrade.iam.api_user.v1.ApiUserService/ActivateApiUser',
                request_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ActivateApiUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
                _registered_method=True)
        self.DeactivateApiUser = channel.unary_unary(
                '/meshtrade.iam.api_user.v1.ApiUserService/DeactivateApiUser',
                request_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.DeactivateApiUserRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
                _registered_method=True)
        self.GetApiUserByKeyHash = channel.unary_unary(
                '/meshtrade.iam.api_user.v1.ApiUserService/GetApiUserByKeyHash',
                request_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.GetApiUserByKeyHashRequest.SerializeToString,
                response_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
                _registered_method=True)


class ApiUserServiceServicer(object):
    """
    ApiUserService manages API user lifecycle and authentication credentials.

    API users represent automated clients that can authenticate with API keys
    and perform operations within a specific group context. Each API user has:
    - A unique identifier and display name
    - Group ownership for resource isolation
    - Role-based permissions for authorization
    - Active/inactive state for access control

    All operations require IAM domain permissions and operate within
    the authenticated group context.
    """

    def GetApiUser(self, request, context):
        """
        Retrieves a single API user by its unique identifier.

        Parameters:
        - name: The resource name in format api_users/{api_user_id}

        Returns:
        - APIUser: Complete API user resource including metadata and roles

        Authorization: Requires ROLE_IAM_ADMIN or ROLE_IAM_VIEWER
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApiUser(self, request, context):
        """
        Creates a new API user with the specified configuration.

        The API user will be created in the authenticated group context
        and assigned the provided roles. The system generates a unique
        identifier and API key for authentication.

        Parameters:
        - api_user: APIUser configuration (name field ignored, assigned by system)

        Returns:
        - APIUser: Newly created API user with generated name and API key

        Authorization: Requires ROLE_IAM_ADMIN
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApiUsers(self, request, context):
        """
        Lists all API users in the authenticated group context.

        Returns all API users that belong to the current group,
        regardless of their active/inactive state.

        Returns:
        - ListApiUsersResponse: Collection of API users in the group

        Authorization: Requires ROLE_IAM_ADMIN or ROLE_IAM_VIEWER
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchApiUsers(self, request, context):
        """
        Searches API users using display name filtering.

        Performs substring matching on API user display names
        within the authenticated group context.

        Parameters:
        - display_name: Substring to search for in display names

        Returns:
        - SearchApiUsersResponse: Collection of matching API users

        Authorization: Requires ROLE_IAM_ADMIN or ROLE_IAM_VIEWER
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActivateApiUser(self, request, context):
        """
        Activates an API user, enabling API key authentication.

        Changes the API user state to active, allowing the associated
        API key to be used for authentication and authorization.

        Parameters:
        - name: The resource name in format api_users/{api_user_id}

        Returns:
        - APIUser: Updated API user with active state

        Authorization: Requires ROLE_IAM_ADMIN
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeactivateApiUser(self, request, context):
        """
        Deactivates an API user, disabling API key authentication.

        Changes the API user state to inactive, preventing the associated
        API key from being used for authentication.

        Parameters:
        - name: The resource name in format api_users/{api_user_id}

        Returns:
        - APIUser: Updated API user with inactive state

        Authorization: Requires ROLE_IAM_ADMIN
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApiUserByKeyHash(self, request, context):
        """
        Retrieves an API user using its API key hash.

        This method is used for authentication flows to lookup
        an API user based on the hash of their API key.

        Parameters:
        - key_hash: Hash of the API key to lookup

        Returns:
        - APIUser: Complete API user resource associated with the key

        Authorization: Requires ROLE_IAM_ADMIN or ROLE_IAM_VIEWER
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ApiUserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetApiUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApiUser,
                    request_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.GetApiUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.SerializeToString,
            ),
            'CreateApiUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApiUser,
                    request_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.CreateApiUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.SerializeToString,
            ),
            'ListApiUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApiUsers,
                    request_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ListApiUsersRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ListApiUsersResponse.SerializeToString,
            ),
            'SearchApiUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchApiUsers,
                    request_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.SearchApiUsersRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.SearchApiUsersResponse.SerializeToString,
            ),
            'ActivateApiUser': grpc.unary_unary_rpc_method_handler(
                    servicer.ActivateApiUser,
                    request_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ActivateApiUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.SerializeToString,
            ),
            'DeactivateApiUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeactivateApiUser,
                    request_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.DeactivateApiUserRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.SerializeToString,
            ),
            'GetApiUserByKeyHash': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApiUserByKeyHash,
                    request_deserializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.GetApiUserByKeyHashRequest.FromString,
                    response_serializer=meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.iam.api_user.v1.ApiUserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.iam.api_user.v1.ApiUserService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ApiUserService(object):
    """
    ApiUserService manages API user lifecycle and authentication credentials.

    API users represent automated clients that can authenticate with API keys
    and perform operations within a specific group context. Each API user has:
    - A unique identifier and display name
    - Group ownership for resource isolation
    - Role-based permissions for authorization
    - Active/inactive state for access control

    All operations require IAM domain permissions and operate within
    the authenticated group context.
    """

    @staticmethod
    def GetApiUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.api_user.v1.ApiUserService/GetApiUser',
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.GetApiUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateApiUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.api_user.v1.ApiUserService/CreateApiUser',
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.CreateApiUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListApiUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.api_user.v1.ApiUserService/ListApiUsers',
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ListApiUsersRequest.SerializeToString,
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ListApiUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchApiUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.api_user.v1.ApiUserService/SearchApiUsers',
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.SearchApiUsersRequest.SerializeToString,
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.SearchApiUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ActivateApiUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.api_user.v1.ApiUserService/ActivateApiUser',
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.ActivateApiUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeactivateApiUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.api_user.v1.ApiUserService/DeactivateApiUser',
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.DeactivateApiUserRequest.SerializeToString,
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetApiUserByKeyHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.iam.api_user.v1.ApiUserService/GetApiUserByKeyHash',
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_service__pb2.GetApiUserByKeyHashRequest.SerializeToString,
            meshtrade_dot_iam_dot_api__user_dot_v1_dot_api__user__pb2.APIUser.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user/v1/user.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n meshtrade/iam/user/v1/user.proto\x12\x15meshtrade.iam.user.v1\"2\n\x04User\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\x12\x14\n\x05roles\x18\x06 \x03(\tR\x05rolesBN\n\x1c\x63o.meshtrade.api.iam.user.v1Z.github.com/meshtrade/api/go/iam/user/v1;userv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034co.meshtrade.api.iam.user.v1Z.github.com/meshtrade/api/go/iam/user/v1;userv1'
  _globals['_USER']._serialized_start=59
  _globals['_USER']._serialized_end=109
# @@protoc_insertion_point(module_scope)



from meshtrade.iam.group.v1 import group_pb2 as _group_pb2
from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from meshtrade.option.v1 import method_type_pb2 as _method_type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetGroupRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class ListGroupsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListGroupsResponse(_message.Message):
    __slots__ = ("groups",)
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_group_pb2.Group]
    def __init__(self, groups: _Optional[_Iterable[_Union[_group_pb2.Group, _Mapping]]] = ...) -> None: ...

class SearchGroupsRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class SearchGroupsResponse(_message.Message):
    __slots__ = ("groups",)
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_group_pb2.Group]
    def __init__(self, groups: _Optional[_Iterable[_Union[_group_pb2.Group, _Mapping]]] = ...) -> None: ...



from buf.validate import validate_pb2 as _validate_pb2
from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from meshtrade.iam.user.v1 import user_pb2 as _user_pb2
from meshtrade.option.v1 import method_type_pb2 as _method_type_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AssignRoleToUserRequest(_message.Message):
    __slots__ = ("email", "group", "role")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    email: str
    group: str
    role: _role_pb2.Role
    def __init__(self, email: _Optional[str] = ..., group: _Optional[str] = ..., role: _Optional[_Union[_role_pb2.Role, str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.wallet.account.v1 import account_pb2 as meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2
from meshtrade.wallet.account.v1 import service_pb2 as meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2


class AccountServiceStub(object):
    """
    AccountService provides access to and management of wallet accounts.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAccount = channel.unary_unary(
                '/meshtrade.wallet.account.v1.AccountService/CreateAccount',
                request_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.CreateAccountRequest.SerializeToString,
                response_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2.Account.FromString,
                _registered_method=True)
        self.GetAccount = channel.unary_unary(
                '/meshtrade.wallet.account.v1.AccountService/GetAccount',
                request_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2.Account.FromString,
                _registered_method=True)
        self.ListAccounts = channel.unary_unary(
                '/meshtrade.wallet.account.v1.AccountService/ListAccounts',
                request_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.ListAccountsRequest.SerializeToString,
                response_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.ListAccountsResponse.FromString,
                _registered_method=True)
        self.SearchAccounts = channel.unary_unary(
                '/meshtrade.wallet.account.v1.AccountService/SearchAccounts',
                request_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.SearchAccountsRequest.SerializeToString,
                response_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.SearchAccountsResponse.FromString,
                _registered_method=True)


class AccountServiceServicer(object):
    """
    AccountService provides access to and management of wallet accounts.
    """

    def CreateAccount(self, request, context):
        """
        Creates a new wallet account.
        This is a write operation restricted to administrative roles.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """
        Retrieves a single wallet account by its unique number.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccounts(self, request, context):
        """
        Retrieves a list of all accounts for the authenticated principal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchAccounts(self, request, context):
        """
        Searches for accounts based on a partial label match.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.CreateAccountRequest.FromString,
                    response_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2.Account.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.GetAccountRequest.FromString,
                    response_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2.Account.SerializeToString,
            ),
            'ListAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccounts,
                    request_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.ListAccountsRequest.FromString,
                    response_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.ListAccountsResponse.SerializeToString,
            ),
            'SearchAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchAccounts,
                    request_deserializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.SearchAccountsRequest.FromString,
                    response_serializer=meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.SearchAccountsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.wallet.account.v1.AccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.wallet.account.v1.AccountService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AccountService(object):
    """
    AccountService provides access to and management of wallet accounts.
    """

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.wallet.account.v1.AccountService/CreateAccount',
            meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.CreateAccountRequest.SerializeToString,
            meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.wallet.account.v1.AccountService/GetAccount',
            meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.GetAccountRequest.SerializeToString,
            meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2.Account.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.wallet.account.v1.AccountService/ListAccounts',
            meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.ListAccountsRequest.SerializeToString,
            meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.ListAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SearchAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.wallet.account.v1.AccountService/SearchAccounts',
            meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.SearchAccountsRequest.SerializeToString,
            meshtrade_dot_wallet_dot_account_dot_v1_dot_service__pb2.SearchAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Code generated by protoc-gen-meshpy. DO NOT EDIT.
# source: meshtrade/trading/market_order/v1/service.proto

"""
MarketOrderService gRPC service wrapper with authentication, timeouts, and resource management.

This module provides a high-level gRPC service for the MarketOrderService service that combines
the service interface with resource management capabilities, providing authentication,
timeouts, and proper connection handling.
"""

from datetime import timedelta
from typing import Optional

from meshtrade.common import BaseGRPCClient
from meshtrade.iam.api_user.v1.api_credentials import find_credentials

from .service_options_meshpy import ServiceOptions
from .service_pb2 import (
GetMarketOrderRequest,
MarketOrder,
)
from .service_pb2_grpc import MarketOrderServiceStub


def _create_marketorderservice_stub(channel):
    """Factory function to create MarketOrderServiceStub from gRPC channel."""
    return MarketOrderServiceStub(channel)


class MarketOrderService(BaseGRPCClient):
    """MarketOrderService gRPC service with authentication, timeouts, and resource management.

    This service provides a complete implementation of the MarketOrderService with proper authentication, timeout handling, and automatic resource cleanup.

    Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/trading/market_order/v1

    Basic service usage with default SDK Configuration:
    ```python
    service = MarketOrderService()

    with service:   # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```
        
    With default configuration API credentials are searched for using the standard discovery hierarchy:
    
    1. MESH_API_CREDENTIALS environment variable
    
    2. Default credential file location:
    
    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`
    
    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

    The service may also be configured with custom options:
    ```python
    from .service_options_meshpy import ServiceOptions
    from datetime import timedelta

    options = ServiceOptions(
        url="api.staging.example.com",
        port=443,
        api_key="your-api-key",
        group="groups/your-group-id",
        timeout=timedelta(seconds=60)
    )

    service = MarketOrderService(options)

    with service: # `with` ensures proper clean up of underlying connection after use
        response = service.get_api_user(request)
    ```

    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration
    """

    def __init__(self, options: Optional[ServiceOptions] = None):
        """Construct and initialize the MarketOrderService service.

        Full Service documentation: https://meshtrade.github.io/api/docs/api-reference/trading/market_order/v1

        Args:
            options: Optional ServiceOptions for configuring the service.
                    If None, service is constructed with default configuration.
                    With default configuration API credentials are searched for using the standard discovery hierarchy:
                    
                    1. MESH_API_CREDENTIALS environment variable
                    
                    2. Default credential file location:
                    
                    - Linux:   `$XDG_CONFIG_HOME/mesh/credentials.json` or fallback to `$HOME/.config/mesh/credentials.json`
                    - macOS:   `$HOME/Library/Application Support/mesh/credentials.json`
                    - Windows: `C:\\Users\\<user>\\AppData\\Roaming\\mesh\\credentials.json`      

                    For more information on authentication: https://meshtrade.github.io/api/docs/architecture/authentication

                    For more information on service configuration: https://meshtrade.github.io/api/docs/architecture/sdk-configuration            

        Example:
        ```python
        # construct with default configuration
        service = MarketOrderService()

        # construct with custom configuration
        options = ServiceOptions(
            url="api.example.com",
            api_key="your-key",
            group="groups/your-group"
        )
        service = MarketOrderService(options)
        ```
        """
        if options is None:
            options = ServiceOptions()

        # Initialize the base client with all common functionality
        super().__init__(
            service_name="MarketOrderService",
            stub_factory=_create_marketorderservice_stub,
            find_credentials_func=find_credentials,
            url=options.url,
            port=options.port,
            api_key=options.api_key,
            group=options.group,
            timeout=options.timeout,
            tls=options.tls,
        )

    def get_market_order(self, request: GetMarketOrderRequest, timeout: Optional[timedelta] = None) -> MarketOrder:
        """GetMarketOrder method.

        Args:
            request: The GetMarketOrder request message
            timeout: Optional timeout override for this call

        Returns:
            The GetMarketOrder response message

        Raises:
            grpc.RpcError: If the gRPC call fails
            ValueError: If authentication credentials are missing
        """
        return self._execute_method("GetMarketOrder", request, timeout)


# Create aliases to match expected exports
MarketOrderServiceGRPCClient = MarketOrderService
MarketOrderServiceGRPCClientInterface = MarketOrderService



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/type/v1/sorting.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/type/v1/sorting.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmeshtrade/type/v1/sorting.proto\x12\x11meshtrade.type.v1*\\\n\x0cSortingOrder\x12\x1d\n\x19SORTING_ORDER_UNSPECIFIED\x10\x00\x12\x15\n\x11SORTING_ORDER_ASC\x10\x01\x12\x16\n\x12SORTING_ORDER_DESC\x10\x02\x42\x46\n\x18\x63o.meshtrade.api.type.v1Z*github.com/meshtrade/api/go/type/v1;typev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.type.v1.sorting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030co.meshtrade.api.type.v1Z*github.com/meshtrade/api/go/type/v1;typev1'
  _globals['_SORTINGORDER']._serialized_start=54
  _globals['_SORTINGORDER']._serialized_end=146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.iam.user.v1 import user_pb2 as meshtrade_dot_iam_dot_user_dot_v1_dot_user__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#meshtrade/iam/user/v1/service.proto\x12\x15meshtrade.iam.user.v1\x1a\x1b\x62uf/validate/validate.proto\x1a meshtrade/iam/role/v1/role.proto\x1a meshtrade/iam/user/v1/user.proto\x1a%meshtrade/option/v1/method_type.proto\"\x88\x04\n\x17\x41ssignRoleToUserRequest\x12\xac\x01\n\x05\x65mail\x18\x01 \x01(\tB\x95\x01\xbaH\x91\x01r7\x10\x01\x18\xfe\x01\x32\x30^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\\.[a-zA-Z]{2,}$\xba\x01U\n\x0e\x65mail.required\x12\x33\x65mail is required and must be a valid email address\x1a\x0esize(this) > 0R\x05\x65mail\x12\x9b\x01\n\x05group\x18\x02 \x01(\tB\x84\x01\xbaH\x80\x01r\x05\x10\x01\x18\xff\x01\xba\x01v\n\x0egroup.required\x12?group name is required and must be between 1 and 255 characters\x1a#size(this) > 0 && size(this) <= 255R\x05group\x12\x9f\x01\n\x04role\x18\x03 \x01(\x0e\x32\x1b.meshtrade.iam.role.v1.RoleBn\xbaHk\x82\x01\x04\x10\x01 \x00\xba\x01\x61\n\rrole.required\x12@role is required and must be a valid role type (not UNSPECIFIED)\x1a\x0eint(this) != 0R\x04role2{\n\x0bUserService\x12l\n\x10\x41ssignRoleToUser\x12..meshtrade.iam.user.v1.AssignRoleToUserRequest\x1a\x1b.meshtrade.iam.user.v1.User\"\x0b\xa0\xb5\x18\x02\xaa\xb5\x18\x03\n\x01\x05\x42N\n\x1c\x63o.meshtrade.api.iam.user.v1Z.github.com/meshtrade/api/go/iam/user/v1;userv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034co.meshtrade.api.iam.user.v1Z.github.com/meshtrade/api/go/iam/user/v1;userv1'
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['email']._loaded_options = None
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['email']._serialized_options = b'\272H\221\001r7\020\001\030\376\00120^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\\.[a-zA-Z]{2,}$\272\001U\n\016email.required\0223email is required and must be a valid email address\032\016size(this) > 0'
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['group']._loaded_options = None
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['group']._serialized_options = b'\272H\200\001r\005\020\001\030\377\001\272\001v\n\016group.required\022?group name is required and must be between 1 and 255 characters\032#size(this) > 0 && size(this) <= 255'
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_ASSIGNROLETOUSERREQUEST'].fields_by_name['role']._serialized_options = b'\272Hk\202\001\004\020\001 \000\272\001a\n\rrole.required\022@role is required and must be a valid role type (not UNSPECIFIED)\032\016int(this) != 0'
  _globals['_USERSERVICE'].methods_by_name['AssignRoleToUser']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['AssignRoleToUser']._serialized_options = b'\240\265\030\002\252\265\030\003\n\001\005'
  _globals['_ASSIGNROLETOUSERREQUEST']._serialized_start=199
  _globals['_ASSIGNROLETOUSERREQUEST']._serialized_end=719
  _globals['_USERSERVICE']._serialized_start=721
  _globals['_USERSERVICE']._serialized_end=844
# @@protoc_insertion_point(module_scope)



# Code generated by protoc-gen-meshpy. DO NOT EDIT.
# source: meshtrade/trading/market_order/v1/service.proto

"""
Configuration options for MarketOrderService gRPC service.
This module provides a clean, extensible way to configure the service with optional
parameters while maintaining backward compatibility and readability.
"""

from datetime import timedelta


class ServiceOptions:
    """Configuration options for MarketOrderService gRPC service.

    This class provides a clean, extensible way to configure the service with optional
    parameters while maintaining backward compatibility and readability.
    """

    def __init__(
        self,
        tls: bool = True,
        url: str | None = None,
        port: int | None = None,
        api_key: str | None = None,
        group: str | None = None,
        timeout: timedelta = timedelta(seconds=30),
    ):
        """Initialize service options.

        Args:
            tls: Whether to use TLS encryption for the gRPC connection.
                When True, establishes a secure connection using TLS.
                When False, uses an insecure connection.
                Default: True (secure connection)

            url: The server hostname or IP address (e.g., "api.example.com", "localhost").
                Default: Uses DEFAULT_GRPC_URL from common module

            port: The server port number (e.g., 443 for HTTPS, 8080 for development).
                Default: Uses DEFAULT_GRPC_PORT from common module

            api_key: The API key string (without "Bearer " prefix) for authentication.
                The API key will be sent as a Bearer token in the Authorization header.
                This is the primary authentication method for service-to-service communication.

            group: The group resource name in format groups/{group_id} required for all API requests.
                The group determines the authorization context for operations
                and is sent as an "x-group" header with every request.

            timeout: The default timeout for all gRPC method calls.
                This timeout applies to individual method calls and helps prevent hanging requests.
                If a request takes longer than the specified timeout, it will be cancelled.
                Default: 30 seconds
        """
        self.tls = tls
        self.url = url
        self.port = port
        self.api_key = api_key
        self.group = group
        self.timeout = timeout


# Create alias to match expected exports
ClientOptions = ServiceOptions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/market_order/v1/market_order.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/market_order/v1/market_order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4meshtrade/trading/market_order/v1/market_order.proto\x12!meshtrade.trading.market_order.v1\"%\n\x0bMarketOrder\x12\x16\n\x06number\x18\x01 \x01(\tR\x06numberBn\n(co.meshtrade.api.trading.market_order.v1ZBgithub.com/meshtrade/api/go/trading/market_order/v1;market_orderv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.market_order.v1.market_order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(co.meshtrade.api.trading.market_order.v1ZBgithub.com/meshtrade/api/go/trading/market_order/v1;market_orderv1'
  _globals['_MARKETORDER']._serialized_start=91
  _globals['_MARKETORDER']._serialized_end=128
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/group/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/group/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.iam.group.v1 import group_pb2 as meshtrade_dot_iam_dot_group_dot_v1_dot_group__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$meshtrade/iam/group/v1/service.proto\x12\x16meshtrade.iam.group.v1\x1a\"meshtrade/iam/group/v1/group.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"%\n\x0fGetGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"\x13\n\x11ListGroupsRequest\"K\n\x12ListGroupsResponse\x12\x35\n\x06groups\x18\x01 \x03(\x0b\x32\x1d.meshtrade.iam.group.v1.GroupR\x06groups\")\n\x13SearchGroupsRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"M\n\x14SearchGroupsResponse\x12\x35\n\x06groups\x18\x01 \x03(\x0b\x32\x1d.meshtrade.iam.group.v1.GroupR\x06groups2\xdc\x02\n\x0cGroupService\x12`\n\x08GetGroup\x12\'.meshtrade.iam.group.v1.GetGroupRequest\x1a\x1d.meshtrade.iam.group.v1.Group\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12q\n\nListGroups\x12).meshtrade.iam.group.v1.ListGroupsRequest\x1a*.meshtrade.iam.group.v1.ListGroupsResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x12w\n\x0cSearchGroups\x12+.meshtrade.iam.group.v1.SearchGroupsRequest\x1a,.meshtrade.iam.group.v1.SearchGroupsResponse\"\x0c\xa0\xb5\x18\x01\xaa\xb5\x18\x04\n\x02\x05\x06\x42Q\n\x1d\x63o.meshtrade.api.iam.group.v1Z0github.com/meshtrade/api/go/iam/group/v1;groupv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.group.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035co.meshtrade.api.iam.group.v1Z0github.com/meshtrade/api/go/iam/group/v1;groupv1'
  _globals['_GROUPSERVICE'].methods_by_name['GetGroup']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['GetGroup']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_GROUPSERVICE'].methods_by_name['ListGroups']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['ListGroups']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_GROUPSERVICE'].methods_by_name['SearchGroups']._loaded_options = None
  _globals['_GROUPSERVICE'].methods_by_name['SearchGroups']._serialized_options = b'\240\265\030\001\252\265\030\004\n\002\005\006'
  _globals['_GETGROUPREQUEST']._serialized_start=173
  _globals['_GETGROUPREQUEST']._serialized_end=210
  _globals['_LISTGROUPSREQUEST']._serialized_start=212
  _globals['_LISTGROUPSREQUEST']._serialized_end=231
  _globals['_LISTGROUPSRESPONSE']._serialized_start=233
  _globals['_LISTGROUPSRESPONSE']._serialized_end=308
  _globals['_SEARCHGROUPSREQUEST']._serialized_start=310
  _globals['_SEARCHGROUPSREQUEST']._serialized_end=351
  _globals['_SEARCHGROUPSRESPONSE']._serialized_start=353
  _globals['_SEARCHGROUPSRESPONSE']._serialized_end=430
  _globals['_GROUPSERVICE']._serialized_start=433
  _globals['_GROUPSERVICE']._serialized_end=781
# @@protoc_insertion_point(module_scope)
